@@ -2,6 +2,6 @@ const path = require("path");
 
 module.exports = {
   process(src, filename, config, options) {
-    return "module.exports = " + JSON.stringify(path.basename(filename)) + ";";
+    return `module.exports = ${JSON.stringify(path.basename(filename))};`;
   },
-};Tra;
+};
